
sjlog using logs/rs1,replace
clear
input str8 country str7 tradeflow Yr1990 Yr1991
Armenia imports 105 120 
Armenia exports 90 100 
Bolivia imports 200 230 
Bolivia exports 80 115 
Colombia imports 100 105 
Colombia exports 70 71 
end
reshape long Yr, i(country tradeflow)
sjlog close, replace

sjlog using logs/rs2,replace
rename _j year
reshape wide Yr, i(country year) j(tradeflow) string
sjlog close, replace

sjlog using logs/bizday1, replace
clear
freduse DTB3
rename daten caldate
tsset caldate
keep if tin(1jan2007,)
label variable caldate date
sjlog close, replace

sjlog using logs/bizday2, replace
quietly generate byte notmiss = !missing(DTB3)
quietly generate seqdate = cond(notmiss, sum(notmiss), .)
tsset seqdate
sjlog close, replace

sjlog using logs/bizday3, replace
quietly generate dDTB3 = 100 * D.DTB3
label variable dDTB3 "Daily change in 3-mo Treasury rate (bp)"
tsset caldate
format caldate %tdCCYY
tsline dDTB3, yline(0) ylabel(,angle(0))
sjlog close, replace

graph export fig6_3.eps, replace

sjlog using logs/bizday4, replace
tsset seqdate
quietly generate dcal = D.caldate if !missing(seqdate)
quietly generate month = mofd(caldate) if !missing(seqdate)
format %tm month
sort month (seqdate)
quietly by month: generate adjchange = sum(dDTB3/sqrt(dcal))
quietly by month: generate sumchange = adjchange if _n==_N & !missing(month)
format sumchange %10.5f
list month sumchange if !missing(sumchange), separator(0) noobs
sjlog close, replace

sjlog using logs/bizday5, replace
clear
freduse DTB3
rename daten caldate
bcal create treascal, from(caldate) generate(bcaldate) personal replace
sjlog close, replace

sjlog using logs/bizday6, replace
tsset bcaldate
tsreport
sjlog close, replace

sjlog using logs/cb5a1,replace
use cb5a, clear
list
sjlog close, replace

sjlog using logs/cb5a2, replace
egen rowid = concat(state year)
reshape long cand, i(rowid) j(candnr)
list
save cb5along, replace
sjlog close, replace

sjlog using logs/cb5a3, replace
bysort state cand: generate byte last=(_n == _N)
egen totcand = total(last), by(state)
drop last
quietly reshape wide
list, sepby(state)
reshape long cand, i(rowid) j(candnr)
bysort state cand: generate byte last=(_n == _N)
tabstat last, stat(sum) nototal by(state)
sjlog close, replace

sjlog using logs/cb5a5, replace
use cb5along, clear
egen indivcount = tag(state cand)
egen totcand = total(indivcount), by(state)
tabstat totcand, nototal by(state)
sjlog close, replace

*sjlog using logs/ch6.5.rev2, replace
*sjlog using logs/ch6.5.rev3, replace
sjlog using logs/ch6.5.rev, replace
use airquality, clear
// estimate with OLS
quietly regress so2 pop manuf wind 
margins, eyex(*) atmeans
matrix nu = r(b)
estadd scalar nu = nu[1,1]
matrix nu = r(V)
estadd scalar nuse = sqrt(nu[1,1])
estimates store one
// reestimate using IV
quietly ivregress 2sls so2 (pop = temp precip) manuf wind
margins, eyex(*) atmeans
matrix nu = r(b)
estadd scalar nu = nu[1,1]
matrix nu = r(V)
estadd scalar nuse = sqrt(nu[1,1])
estimates store two
sjlog close, replace

sjlog using logs/ch6.5a.rev, replace
esttab one two, mtitles("OLS" "IV") stat(nu nuse, labels("Elas.(pop)" "SE"))
sjlog close, replace

*sjlog using logs/ch6.5b.rev2, replace
sjlog using logs/ch6.5b.rev, replace
quietly summarize so2, detail
generate hiso2 = (so2 > r(p50)) & !missing(so2)
summarize precip, meanonly
generate hiprecip = (precip > r(mean)) & !missing(precip)
quietly probit hiso2 pop manuf
margins, dydx(*) post 
estimates store three
quietly probit hiso2 pop manuf i.hiprecip
margins, dydx(*) post 
estimates store four
estimates save four, replace
sjlog close, replace

sjlog using logs/ch6.5c.rev, replace
esttab three four, margin drop(0.hiprecip) nodep num nomtitles ///
title("Factors influencing high SO2 concentration")
sjlog close, replace

sjlog using logs/ch6.5d.rev, replace
quietly probit hiso2 pop manuf i.hiprecip
summarize manuf if e(sample)
quietly margins, dydx(manuf) at(manuf=(50(50)750))
marginsplot
sjlog close, replace

graph export fig6_5.eps, replace

sjlog using logs/ch6.6, replace
use air2, clear
* put a timeseries calendar on the data
tsmktim ym, start(1949m1)
* get the month number
generate mnr = month(dofm(ym))
* find the end-of-quarter months
generate eoq = (mod(mnr, 3) == 0)
list ym mnr eoq air in 1/18, separator(3) noobs
sjlog close, replace

sjlog using logs/ch6.6a, replace
// keep only last month of quarter
preserve
keep if eoq
tsmktim yq, start(1949q1)
list yq air in 1/16, separator(4) noobs
sjlog close, replace

sjlog using logs/ch6.6b, replace
// sum the values over the quarter
restore, preserve
generate qtr = qofd(dofm(ym))
format qtr %tq
collapse (sum) airsum=air, by(qtr)
tsmktim yq, start(1949q1)
list yq airsum in 1/16, separator(4) noobs
sjlog close, replace

sjlog using logs/ch6.6c, replace
// average the values over the quarter
restore, preserve
generate qtr = qofd(dofm(ym))
format qtr %tq
collapse airavg=air, by(qtr)
tsmktim yq, start(1949q1)
list yq airavg in 1/16, separator(4) noobs
sjlog close, replace

sjlog using logs/ch6.6d, replace
restore
tsset ym
tscollap (last) aireoq=air (sum) airsum=air (mean) airavg=air, to(q) gen(yq)
list in 1/16, separator(4) noobs
sjlog close, replace

sjlog using logs/ch6.8sga, replace
sysuse auto, clear
generate rep1 = rep78 if rep78 <= 3
generate rep2 = rep78 if rep78 > 3
oprobit rep1 mpg weight length, nolog
estimates store one
oprobit rep2 mpg weight length, nolog
estimates store two
suest one two
test _b[one_rep1:mpg] = _b[two_rep2:mpg]
sjlog close, replace

sjlog using logs/ch6.8sgb, replace
gsem (rep1 <-mpg weight length) (rep2 <-mpg weight length), oprobit vce(robust) nolog
test _b[rep1:mpg] = _b[rep2:mpg]
sjlog close, replace

sjlog using logs/ch6.9a, replace
webuse pennxrate, clear
keep if g7
keep ppp xrate realxrate year country
reshape wide ppp xrate realxrate, i(year) j(country) string
tsset year
sjlog close, replace

sjlog using logs/ch6.9b, replace
foreach x in CAN FRA GBR GER ITA JPN {
        quietly var xrate`x' ppp`x' realxrate`x' if tin(,2003), lags(1/2)
        fcast compute f_, step(8) dynamic(2004) nose
}
reshape long xrate ppp realxrate f_xrate f_ppp f_realxrate, ///
i(year) j(country) string
encode country, gen(cty)
tsset cty year
tabstat f_realxrate if tin(2004,), by(country) stat(N mean sd)
xtline realxrate f_realxrate, scheme(s2mono) ylabel(,angle(0)) ///
yline(1) saving(fig6_9, replace)
sjlog close, replace

graph export fig6_9.eps, replace

webuse pennxrate, clear
keep if g7
keep ppp xrate realxrate year country
reshape wide ppp xrate realxrate, i(year) j(country) string
tsset year
sjlog using logs/ch6.9c, replace
tsappend, add(8)
foreach x in CAN FRA GBR GER ITA JPN {
        quietly var xrate`x' ppp`x' realxrate`x' if tin(,2003), lags(1/2)
        estimates store `x'
        quietly forecast create, replace
        quietly forecast estimates `x'
        quietly forecast solve, prefix(f_) begin(2004)
}
reshape long xrate ppp realxrate f_xrate f_ppp f_realxrate, ///
i(year) j(country) string
encode country, gen(cty)
tsset cty year
tabstat f_realxrate if tin(2004,), by(country) stat(N mean sd)
sjlog close, replace

sjlog using logs/ch6.10a, replace
webuse lutkepohl2, clear
quietly var dln_inv dln_inc dln_consump
irf create order1, set(myirf1, replace)
irf table oirf coirf fevd, impulse(dln_inc) response(dln_consump) noci
sjlog close, replace

sjlog using logs/ch6.10b, replace
use myirf1.irf, clear
describe
sjlog close, replace

sjlog using logs/ch6.10c, replace
list step oirf coirf fevd if impulse=="dln_inc" & response=="dln_consump", ///
noobs separator(0)
sjlog close, replace

sjlog using logs/ch6.10d, replace
format oirf %9.5f
format coirf %9.5f
format fevd %9.5f
local impulse dln_inc
local response dln_consump
local imp = subinstr("`impulse'","_"," ",1)
local resp = subinstr("`response'","_"," ",1)
listtab_vars step oirf coirf fevd, substitute(varlab) delim("&") ///
local(headrow) end("\cr")
local title "\noindent{\bf Impulse: `imp' ~~~~Response: `resp'}"
listtab step oirf coirf fevd if impulse=="`impulse'" & response=="`response'" ///
using ch6.10_tab.tex, ///
head(`"`title'\\ \begin{tabular}{lrrr}\cr `headrow' \hline"') ///
foot("\hline\end{tabular}") rstyle(tabular) replace
sjlog close, replace
