
sjlog using logs/ch8.3, replace
use grunfeld, clear
generate linvest = log(invest)
mvsumm LD.linvest, generate(invrate) stat(mean) window(3) end
sjlog close, replace

sjlog using logs/ch8.3a, replace
label variable invrate "Three-year average investment rate"
tsline invrate if inrange(company, 1, 4) & year >= 1937, by(company, title(" ")) ///
   yline(0) yscale(range(-0.2 0.3)) ytick(-0.2(0.1)0.3) ylabel(-0.2(0.1)0.3, angle(0)) ///
   scheme(s2mono)
sjlog close, replace

graph display, xsize(5) ysize(4)
graph export fig8_3.eps, replace

sjlog using logs/ch8.3b, replace
quietly rolling r(mean), window(3) saving(ldinvest, replace): summarize LD.linvest
sjlog close, replace

sjlog using logs/ch8.3c, replace
preserve
use ldinvest, clear
rename (end _stat_1) (year rolling_ldinvest)
keep if year >= 1939
xtset company year
save ldinvest, replace
restore
merge m:1 company year using ldinvest
drop _merge
summarize invrate rolling_ldinvest
sjlog close, replace

sjlog using logs/ch8.4, replace
use fictprice, clear
quietly generate dscorr = 100 * (p - p[_n-1])
quietly generate deld = date - date[_n-1]
quietly generate dscorrd = dscorr / sqrt(deld)
quietly generate ds2 = dscorrd^2
sjlog close, replace

sjlog using logs/ch8.4a, replace
generate mon = mofd(date)
bysort mon: generate cumds2 = sum(ds2)
sjlog close, replace

sjlog using logs/ch8.4b, replace
quietly bysort mon: generate ssq = sqrt(cumds2) if _n == _N
sjlog close, replace

sjlog using logs/ch8.4c, replace
drop if ssq == .
tsset mon, monthly
save myvolat, replace
sjlog close, replace

sjlog using logs/ch8.4d, replace
label variable mon month
label variable ssq "Estimated volatility"
tsline ssq, title("Monthly volatility from Merton method") ylabel(,angle(0)) scheme(s2mono)
sjlog close, replace

graph display, xsize(5) ysize(4)
graph export fig8_4.eps, replace

sjlog using logs/ch8.6a, replace
clear all
local fyear 1990
local lyear 2013
local mycountry France Germany Italy Spain Austria Cyprus
local ff 0
foreach j of local mycountry {
	forvalues i=`fyear'/`lyear' {
		import excel using "`j'.xlsx" , sheet("`i'") cellrange(H7) clear 
		generate year=`i'
		quietly destring I, replace force
		capture quietly destring J, replace force
		if `i'==`fyear' {
			quietly drop if mi(I)
			quietly save "`j'.dta" , replace
		}
		else quietly { 
			drop if mi(I)
			append using "`j'.dta", force
			save "`j'", replace 
		}
	}
	rename H model
	rename I reg_curr
	capt rename J reg_pre
	generate country= "`j'"
	gsort year -reg_curr
	quietly save "`j'", replace
	if !`ff' {
		quietly save allcty, replace
		local ++ff
		local fcty `j'
	}
}
sjlog close, replace

sjlog using logs/ch8.6b, replace
use allcty, clear
local restcty: list mycountry - fcty
quietly append using `restcty', force
save allcty, replace
tabulate year country
sjlog close, replace

